function [ my_omega1, my_b1 ]= gaussian_pulse(flip_angle, duration, my_times)
%   my_omega1 = gaussian_pulse(flip_angle, duration, my_times)
%
% function returns the value of omega1 for a Gaussian pulse,
%  at each point in time vector (my_times)
%  when given a flip angle and duration
%
% Ref: Bernstein, King, and Zhou, Handbook of MRI Pulse Sequences, Chapter 4
%

%
%	Ives Levesque, 2011
%
%------------------------------------------------------------------------------

my_gamma = 2*pi*4258;
dt = (my_times(end) - my_times(1))/(length(my_times)-1);

% my_sigma determined assuming that pulse duration is set at 60 dB amplitude,
%   according to Chapter 4 in Handbook of MRI Pulse Sequences
my_sigma = duration / 7.434;

gaussian_wf = exp(-((my_times-(duration/2)).^2)/(2*my_sigma^2));

% compute pulse amplitude to scale for flip angle
my_integral = sum(gaussian_wf)*dt;
amplitude = pi*flip_angle/180 / (my_gamma * my_integral);

% scale pulse waveform
my_b1 = amplitude * gaussian_wf;
my_omega1 = my_gamma * amplitude * gaussian_wf;


return