function g_Super = superlorentzianLineshape(delta, T_2r)
% function g_Super = superlorentzian_lineshape(delta, T_2r)
%   
%   delta in Hz, T_2r in seconds
%   returns the lineshape amplitude of a SuperLorentzian pool of given T_2r, at the indicated frequency
%
%   scaled such that Rrf = pi*(omega1^2)*line
%
%------------------------

%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Ye Gu, Ives Levesque, Nikola Stikov (2011)
%%%%%%%%%%%%%%%%%%%%%%%%%%

% calculation might be better performed with built-in integration utility?  _IRL
n_delta = length(delta);
% this might be overkill?  _IRL
%du = 0.0000001;
du  = 0.0001;
u = 0:du:1;

u_space = u'*ones(1,n_delta);
delta_space = ones(length(u),1)*delta;
    
cos_term = 3.*u_space.^2-1;
kernel = exp(-2.*((2*pi.*delta_space*T_2r)./(cos_term)).^2);
integrand = (1./abs(cos_term)).*kernel*du;
    
g_Super = (T_2r/pi)*sqrt(2*pi)*sum(integrand);

