function result = cw_model(p, amplitudes, offsets, lineshape )
%
% function cw_model(p, amplitudes, offsets, lineshape )
%
%	calculate signal from a CW saturation experiment according to the analytical steady-state solution of the two-pool model
%
% inputs:
%	p: 	    input parameters
%		    [f r t2f t2r r1f r1r] (f = liquid/lorentzian, r = semi-solid)
%	amplitudes: CW amplitudes (Hz)
%	offsets:    CW frequency offsets (Hz)
%	lineshape:  string to select the semi-solid pool lineshape (Lorentzian, Gaussian, SuperLorentzian)
%
% ref: Henkelman et al. Magn Reson Med (1993) 29:759
%

%
%	Ives Levesque, 2011
%	ives@stanford.edu
%
%------------------------------------------------------------------------------

% parse input parameters
r1f = p(5);
t2f = p(3);
m0f = 1;

r1r = p(6);
t2r = p(4);
m0r = p(1);

r = p(2);

lineshape_fcn = [lineshape 'Lineshape'];

result = zeros(length(amplitudes), length(offsets));


% loop over pulse amplitudes to compute signal equation
for ampl = 1:length(amplitudes)

    omega1 = amplitudes(ampl);

    rrfb = pi*omega1^2*feval(lineshape_fcn, offsets, t2r);
	rrfa = pi*omega1^2*lorentzianLineshape(offsets,t2f);
    
    numerator = r1r*(r*m0r/r1f) + rrfb + r1r + r;
    denominator = (r*m0r/r1f)*(r1r+rrfb) + (1 + (omega1./(2*pi*offsets)).^2*(1/(r1f*t2f))).*(r1r + rrfb + r);

    result(ampl,:) = numerator./denominator;
    
end

