function [omega_cwpe, b1_cwpe, p1, p2] = cwpe(flip_angle, duration, tr)
%       [omega_cwpe, b1_cwpe, p1, p2] = cwpe(flip_angle, duration, tr)
%
%	A function to compute the CWPE amplitude for a Gaussian pulse
%
%	flip_angle:	pulse flip angle in degrees
%	duration:	pulse duration in msec
%	tr:			pulse repetition time in msec
%
%	ref: Ramani et al. MRI 2002
%

%
%	Ives Levesque, 2011
%	ives@stanford.edu
%
%------------------------------------------------------------------------------

% match Ramani notation
theta_sat = flip_angle;
tau_sat = duration;

% constants
my_gamma = 2*pi*4258;	% Hz/Gauss
dt = 1e-6;
% time vector
my_times = [0:dt:duration-dt];

% definition of Gaussian pulse waveform, in units of rads/sec
my_omega1 = gaussian_pulse(flip_angle, duration, my_times);

% compute pulse waveform, amplitude, and mean
square_height = max(my_omega1);
mean_height = mean(my_omega1);


%-- ratio of the mean amplitude of saturation pulse to that of a rect pulse of same (max) amplitude (= height)
p1 = mean_height/square_height;

b_sat = theta_sat/((180/pi)*my_gamma*p1*tau_sat);


%-- ratio of square of mean amplitude of sat pulse to square of amplitude of rect pulse of same height
mean_sq_height = mean(my_omega1.^2);
p2 = mean_sq_height/square_height^2;


p_sat = p2*b_sat^2*tau_sat/tr;

b1_cwpe = sqrt(p_sat);
omega_cwpe = my_gamma*b1_cwpe;


% Error check
% compare to equation in Erratum, Tofts et al. MRM 2005 53:492
%verify = sqrt(p2 / (tau_sat * tr)) * theta_sat * pi / (p1 * 180);

