function z = obj_cw_model(params, measurements, t1obs, lineshape, amplitudes, offsets, r1r, def_params, fitmask)
%
% z = obj_cw_model(params, measurements, t1obs, lineshape, amplitudes, offsets [, r1r])
%s
%   objective function for fitting the two-pool model of MT under CW saturation
%
% inputs:
%  params(1) = f
%  params(2) = r
%  params(3) = t2f
%  params(4) = t2r
%
%  default value of r1r is be 1 s^-1
%  r1f is computed from t1obs and r1r
%  default values of parameters (def_params) must be passed
%  fit_mask: array to mask which parameters must be estimated
%

%
%	Ives Levesque, 2011
%	ives@stanford.edu
%
%------------------------------------------------------------------------------

params(fitmask == 0) = def_params(fitmask == 0);

% fit for all parameters except r1r
params(6) = r1r;

rd = params(6) - 1/t1obs;
kf = params(2)*params(1);
params(5) = 1/t1obs  - kf * rd /(rd + params(2));

tmp = cw_model(params, amplitudes, offsets, lineshape);
if size(measurements) ~= size(tmp)
    error 'dimensions mismatch'
end

z = sum(sum((measurements - tmp).^2));
