function [m_after, time_after] = applySquarePulseQuick(m_before, time_before, flip, duration, freq, m0, t1, t2, varargin)
% [m_after, time_after] = applySquarePulseQuick(m_before, time_before, flip, duration, freq, m0, t1, t2, varargin)
%
% computes magnetization resulting from a square pulse applied to simulated sample
% uses instantaneous rotation of magnetization (solution to Bloch equation ignoring relaxation)
% returns resulting magnetization and time
%
%   enter flip angle and phase (relative to X) in RADIANS!
%


%
%   Ives Levesque, 2011
%
%------------------------------------------------------------------------------------------------



%--- get pulse phase ----------------------------------------------------------------------------

if nargin == 9
    phase = varargin{1};
else
    phase = 0;
end

%--- warning for possible deviations from correct answer ----------------------------------------

if sum(duration > 0.02*t2(1))
    warning(sprintf('Pulse duration long enough relative to T2 to cause appreciable deviation from correct answer.\n'))
elseif flip > pi
    warning(sprintf('Pulse angles greater than 180 degrees may cause appreciable deviation from correct answer.\n'))
end


%--- warning for off-resonance pulses  ----------------------------------------------------------

if freq ~=0
    warning('Function cannot apply pulses off-resonance.')
end


%---- compute resulting magnetization -----------------------------------------------------------

m_after = rot_z(-phase) * rot_x(flip) * rot_z(phase) * m_before;

time_after = time_before + duration;




%------------------------------------------------------------------------------------------------
%------------------------------------------------------------------------------------------------
%---- FUNCTIONS
%------------------------------------------------------------------------------------------------
%------------------------------------------------------------------------------------------------


%------------------------------------------------------------------------------------------------
function matrix = rot_z(angle)

matrix = [ cos(angle) sin(angle) 0;
          -sin(angle) cos(angle) 0;
           0          0          1];


%------------------------------------------------------------------------------------------------
function matrix = rot_x(angle)

matrix = [ 1  0          0;
           0  cos(angle) sin(angle);
           0 -sin(angle) cos(angle)];
