function a = getCWSatMatrix(num_pools, t1, t2, k_for, k_rev, w, my_omega1, delta)
% a = getCWSatMatrix(num_pools, t1, t2, k_for, k_rev, w, my_omega1, delta);
%
%   omega1 = pulse envelope in rads/sec (=2*pi*B1)
%   delta  = pulse offset frequency in rads/s (= 2*pi*delta in Hz)
%
% Function returns the 2-pool Bloch matrix "A" for CW saturation
%	such that dM/dT = A*M +B*M0, where B0 is the appropriate R1 relaxation vector
%
% assumes no exchange of XY magnetization between solid-liquid pool pair   
% includes direct saturation  
%

%
%   Ives Levesque, 2011
%
%-------------------------------------------------------------------------------------------------------

% initialize result
a = zeros(3*num_pools);

if length(w) ~= 1
  error('Number of CW saturation rates are wrong.')
end

% add T1 relaxation, T2 decay 
a = a - diag([0        0        1/t1(1)  0        0        1/t1(2)  ]);
a = a - diag([1/t2(1)  1/t2(1)  0        1/t2(2)  1/t2(2)  0        ]);

% add exchange
% neglect XY exchange from solid to liquid
a = a - diag([0 0 k_for 0 0 0     ]);
a = a - diag([0 0 0     0 0 k_rev ]);
% add more exchange - off-diagonal terms
a = a + diag([0 0 k_rev],3);
a = a + diag([0 0 k_for],-3);

% add saturation
a = a - diag([0        0        0  	     0        0        w  ]);

% add off-resonance effect on liquid pool
a = a - diag([delta 0 0 0 0 ],+1);
a = a + diag([delta 0 0 0 0 ],-1);

% add direct effect on liquid pool
a = a - diag([0 my_omega1 0 0 0 ],+1);
a = a + diag([0 my_omega1 0 0 0 ],-1);