function [model_system, expt, sim_result] = simQmt()
% [model_system, expt, sim_result] = simQmt()
%
% wrapper for basic simulation of Pulsed Saturation SPGR experiment on two compartments with exchange
%

%
%   Ives Levesque 2011
%
%--------------------------------------------------------------------------------------------------------


%----- prep simulations ---------------------------------------------------------------------------------

%----- set up experiment

exptProtocol;

for index = 1:length(sat_flips);  % run as many experiment there are saturation angles

    expt(index).te = 0;  % set TE = 0, to ignore T2* effects
    expt(index).total_sat_dur = sat_duration(index);
    expt(index).sat_pulse_type = sat_pulse_type;
    expt(index).excite_dur = 0.0001;  % 100 microsec excite pulse
    expt(index).spoil_grad_dur = 0;   % instantaneous for now
    expt(index).excite_phase = 0;
    expt(index).offset = [offset(index,:)];  % already qmt_included no-sat experiment

    expt(index).tr = tr(index);
    expt(index).sat_dur = pulse_duration(index);
    expt(index).excite_flip = excite_flip(index)*pi/180;
    expt(index).sat_flips = sat_flips(index);
    
end


%----- load two-pool MT model parameters
load wm_mt_system_params2.mat;


model_system.m0 = m0;
model_system.t1 = t1;
model_system.t2 = t2;
model_system.k_for = rm0_solid;
model_system.k_rev = rm0_solid*m0(1)/m0(2);
model_system.lineshape_type = 'superlorentzian';



%----- name of results file

results_file = ['sim_results.mat'];


%------ run simulations -------------------------------------------------------------------------------------

sim_kernel = 'simPulsedSatSpgr';

    num_powers = length(expt(1).sat_flips);



% results structure
sim_result = struct('complete', cell(length(expt)), ...
		    'mag_signal', cell(length(expt)), ...
	            'phase_signal', cell(length(expt)), ...
		    'time_elapsed', cell(length(expt)));

for e = 1:length(expt)
        sim_result(e).complete = zeros(num_powers, length(expt(e).offset));
        sim_result(e).mag_signal = sim_result(e).complete;
        sim_result(e).phase_signal = sim_result(e).complete;
        sim_result(e).time_elapsed = sim_result(e).complete;
end

% run each simulation separately
for e = 1:length(expt)  % loop over all experiments
    for a = 1:num_powers
        for o = 1:length(expt(e).offset)

                expt(e).sat_offset = expt(e).offset(o);
                if expt(e).sat_offset == 0  % if this is the baseline (no-sat) simulation
                    expt(e).sat_flip = 0;
                else
                    expt(e).sat_flip = expt(e).sat_flips(a);
                end

                %tic
                % call the sim kernel, with the proper model and experimental parameters
                [mag_tmp, phase_tmp, time_tmp] = feval(sim_kernel, model_system, expt(e));

                sim_result(e).mag_signal(a,o) = mag_tmp;
                sim_result(e).phase_signal(a,o) = phase_tmp;
                sim_result(e).time_elapsed(a,o) = time_tmp;
                sim_result(e).complete(a,o) = 1;

        end
    end
end


index = 1;

for k = 1:length(expt)
    mt_data(k,:) = sim_result(k).mag_signal(1:end-1)./sim_result(k).mag_signal(end);
end

tr = expt(index).tr(index);
excite_flip_angle = excite_flip(index);
sat_flip_angles = sat_flips;
sat_offsets = offset(index,1:end-1)

% compute theoretical R1obs on the fly - could also simulate
b = sum(1./model_system.t1) + model_system.k_for + model_system.k_rev;
c = prod(1./model_system.t1) + model_system.k_rev/model_system.t1(1) + model_system.k_for/model_system.t1(2);
R1obs = 0.5 * ( b - sqrt( b^2 - 4*c ) )
t1obs = 1/R1obs;

pulse_type = 'gaussian pulse'
pulse_duration = expt(1).sat_dur;
mt_model = [model_system.m0(2) model_system.k_rev model_system.t2(1) model_system.t2(2) 1./model_system.t1(1:2) ];
save sim_results.mat tr excite_flip_angle sat_flip_angles sat_offsets mt_data t1obs pulse_type pulse_duration mt_model