function My=solution(alpha, TR, T_rf, F, k_f, T_1f, T_2f, W_exp)

% Analytical solution for pre determined W. 
% Used for fitting data points with fixed W because calculation of W takes time

% Reference: M. Gloor, K. Scheffler, and O. Bieri. "Quantitative
% Magnetization Transfer Imaging Using Balanced SSFP", Magnetic Resonance
% in Medicine 60:691–700 (2008)

alpha=alpha*pi/180;



M_0f=1;

M_0r=F;
R_1f=1/(T_1f);
R_1r=1;
R_2f=1/(T_2f);
k_r=k_f/F;




E_1r=exp(-R_1r*TR);
E_1f=exp(-R_1f*TR);
E_2f=exp(-R_2f*TR);

f_w=exp(-W_exp*T_rf);
f_k=exp(-(k_f+k_r)*TR);

C=F*(1-E_1r)*(1-f_k);
B=1+f_k*(F-f_w*E_1r*(F+1));
A=1+F-f_w*E_1r*(F+f_k);

My=M_0f*sin(alpha)*((1-E_1f)*B+C)./(A-B*E_1f*E_2f-(B*E_1f-A*E_2f)*cos(alpha));

end
