function g_Super = superlorentzianLineshape(delta, T_2r)
% function g_Super = superlorentzian_lineshape(delta, T_2r)
%
%   returns the lineshape amplitude of a SuperLorentzian pool of given T_2r, at the indicated frequency
%
%   input delta in Hz and T_2r in seconds
%
%   scaled such that Rrf = pi*(omega1^2)*line
%
%------------------------

n_delta = length(delta);
du = 0.0000001;
u = 0:du:1;

u_space = u'*ones(1,n_delta);
delta_space = ones(length(u),1)*delta;
    
cos_term = 3.*u_space.^2-1;
kernel = exp(-2.*((2*pi.*delta_space*T_2r)./(cos_term)).^2);
integrand = (1./abs(cos_term)).*kernel*du;
    
g_Super = (T_2r/pi)*sqrt(2*pi)*sum(integrand);

return
