function [alphas, M] = simAlpha(alphas,TR,T_rf,Npulse,NumBin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Shell function to simulate on resonance bSSFP given a series of flip 
%angles

%Calls the simulation function sincsolver

%Input array of desired alphas, TR, T_rf, number of pulses to be simulated
%and number of slices for each pulse

%Output arrays of flip angles and corresponding |M_xy| value
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load('./SimTempData/SimulationParams.mat');

%initializing
M = alphas * 0;

%evaluating amplitude of sinc pulses according to the definition of alpha
x = linspace(0,T_rf,10000);
z = abs(sinc(4/T_rf * (x - (T_rf)/2)));

%amps = alphas /180*pi/integral/4258;
amps = alphas /180*pi/trapz(x,z)/(4258*2*pi);

%iteration to call simulation function at each given alpha
for i = 1:length(amps)
    tic;[t,y] = sincsolver(Npulse,TR,T_rf,amps(i),[0 0 M_0f F*M_0f]',NumBin);toc;
    M(i) = interp1(t,y(2,:),(Npulse*TR - TR/2));
    clear t y
end

%plot results
plot(alphas,M,'.')
end

