function [Trf,M] = simTrf(angle, TR, Trf, Npulse,NumBin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Shell function to simulate on-resonance bSSFP with various T_rf and TR
% (keeping constant 'off' time).

% Input: array of intergers (multiples of original T_rf (2.3e-4)), number
% of pulses and number of slices per pulse

% Output: simulated T_rfs and associated |M_xy|
%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Initializing
% **WARNING**: MATLAB's integration function does not treat sinc functions
% well, Trfs of exact multiples of 2.3e-4 results in a lot of errors when
% computing integrals, thus use 2.3000000001e-4 instead

load('./SimTempData/SimulationParams.mat');

M = Trf * 0;


% Iteration to call simulation function at each T_rf (Fixed flip angle: 35)
for i = 1:length(Trf)
    x=linspace(0, Trf(i), 10000);
    y=abs(sinc(4 / Trf(i) * (x - Trf(i)/2)));
    amp = angle/180*pi/(4258*2*pi)/trapz(x,y);

    tic;[t,y] = sincsolver(Npulse,TR(i),Trf(i),amp,[0 0 M_0f F*M_0f]',NumBin);toc;
    M(i) = interp1(t,y(2,:),(Npulse*TR(i) - (TR(i) - Trf(i))/2));
    clear t y;
end

end
