function [t, y]= sincsolver(pulses,T_r,T_rf,amp,yo,NumBin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Simulation function of on-resonance bSSFP for given amplitude, TR, T_rf,
%IC's, number of pulses and number of slices per pulse

%Input: number of pulses, TR, T_rf, amplitude of pulse, IC's, number of
%slices per pulse

%Output: time, [M_xf, M_yf, M_zf, M_zr], flip angle by this pulse
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




%Initializing
t=[];
y=[];
time=0;

%Nested iteration to simulate with standard ODE solver for given number of
%pulses and given number of slices per pulse, rotating X-Y by 180 degrees
%to simulate alternating pulses
for i=1:pulses 
    for j = 1:NumBin
        [t_temp, y_temp]=ode15s(@(t,y) odes(t,y,T_r,T_rf,amp), [time (time + T_rf / NumBin)], yo);

        t = [t t_temp(2:end)'];
        y = [y y_temp(2:end,:)'];
        yo=y_temp(end,:);

        time=time + T_rf / NumBin;    
        clear t_temp y_temp;
    end
    
    for k = 1:NumBin
        [t_temp, y_temp]=ode15s(@(t,y) odes_temp(t,y), [time (time+(T_r-T_rf)/NumBin)], yo);
        t = [t t_temp(2:end)'];
        y = [y y_temp(2:end,:)'];
        yo=y_temp(end,:);
        time=time+(T_r-T_rf)/NumBin;
        clear t_temp y_temp;
    end
    yo(1) = -yo(1);
    yo(2) = -yo(2);
end


end
